@@ -3,16 +3,17 @@ import os
 import warnings
 import pandas as pd
 
+
 from nctoolkit.cleanup import cleanup
-from nctoolkit.runthis import run_this, run_cdo, tidy_command
+from nctoolkit.runthis import run_cdo, tidy_command
 from nctoolkit.session import session_info, append_safe, remove_safe
-from nctoolkit.show import nc_variables, nc_years, nc_times
+from nctoolkit.show import nc_variables, nc_times
 from nctoolkit.temp_file import temp_file
-from nctoolkit.utils import version_above
 from nctoolkit.api import open_data
 import nctoolkit.api as api
 
-def day_stat(self, operation = None,  x=None):
+
+def day_stat(self, operation=None, x=None):
     """
     Do not use
     """
@@ -20,7 +21,7 @@ def day_stat(self, operation = None,  x=None):
     if not isinstance(operation, str):
         raise ValueError("operation must be a str")
 
-    if operation not in  ["subtract", "divide"]:
+    if operation not in ["subtract", "divide"]:
         raise ValueError("only subtract")
 
     if operation == "subtract":
@@ -55,8 +56,6 @@ def day_stat(self, operation = None,  x=None):
     cleanup()
 
 
-
-
 def arithall(self, stat="divc", x=None):
     """
     Method to add, subtract etc. a constant from a dataset
@@ -67,9 +66,9 @@ def arithall(self, stat="divc", x=None):
         raise ValueError("This does not work on empty datasets!")
 
     # create the system command and run it
-    cdo_command = f"cdo -{stat},{x}"
+    cdo_command = f"-{stat},{x}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command)
 
 
 def operation(self, method="mul", ff=None, var=None):
@@ -85,9 +84,6 @@ def operation(self, method="mul", ff=None, var=None):
         if var not in nc_variables(ff):
             raise ValueError("var supplied is not available in the dataset")
 
-
-   
-
     new = False
     # throw error if the file to operate with does not exist
     if ff is not None:
@@ -96,56 +92,46 @@ def operation(self, method="mul", ff=None, var=None):
 
     # check compatibility
 
-    n_min  = self.contents.nlevels.min()
+    n_min = self.contents.nlevels.min()
 
-    ds = open_data(ff, checks = False)
+    ds = open_data(ff, checks=False)
     contents = ds.contents
 
     n_max = contents.nlevels.max()
 
     if n_max > n_min:
-        raise ValueError(f"Problem raised by incompatible number of vertical levels. {n_max} versus {n_min}. Please check dataset contents.")
+        raise ValueError(
+            f"Problem raised by incompatible number of vertical levels. {n_max} versus {n_min}. Please check dataset contents."
+        )
 
-    if version_above(session_info["cdo"], "1.9.8"):
-        new = True
-    else:
-        warnings.warn("Use CDO>=1.9.10 for smarter operations")
-        self.run()
-
-    bad_vars = False
+    new = True
 
     if var is None:
         for x in self:
             n_vars = len(nc_variables(ff))
             x_vars = len(nc_variables(x))
 
-            #if n_vars > x_vars:
-                #raise ValueError("Incompatible number of variables in datasets!")
+            # if n_vars > x_vars:
+            # raise ValueError("Incompatible number of variables in datasets!")
 
             if n_vars != x_vars:
                 if n_vars > 1:
-                    raise ValueError(
-                        "Incompatible number of variables in datasets!"
-                    )
+                    raise ValueError("Incompatible number of variables in datasets!")
 
     # grab the method string
     if new:
         if method == "mul":
             nc_str = "Multiplying by a"
         if method == "sub":
-            nc_operation = "subtraction"
             nc_str = "Subtracting a"
         if method == "add":
-            nc_operation = "addition"
             nc_str = "Adding a"
         if method == "div":
-            nc_operation = "division"
             nc_str = "Dividing by a"
 
     if new:
         ff_times = nc_times(ff)
         if len(ff_times) <= 1:
-            op_method = "single"
             new = False
             method = method
         else:
@@ -167,8 +153,9 @@ def operation(self, method="mul", ff=None, var=None):
                     .drop(columns="time")
                 )
 
-    if new:
+            ff_times_df = ff_times_df.astype("int")
 
+    if new:
         self1 = self.copy()
 
         if len(self1) == 0:
@@ -186,7 +173,9 @@ def operation(self, method="mul", ff=None, var=None):
                     years = [int(x.split("T")[0].split("-")[0]) for x in x_times]
                     months = [int(x.split("T")[0].split("-")[1]) for x in x_times]
                     days = [int(x.split("T")[0].split("-")[2]) for x in x_times]
-                    df = pd.DataFrame({"year": years, "month": months, "day": months})
+                    df = pd.DataFrame(
+                        {"year": years, "month": months, "day": months}
+                    ).astype("int")
                     self_times.append(df)
 
                 else:
@@ -196,7 +185,7 @@ def operation(self, method="mul", ff=None, var=None):
                     hours = [x.hour for x in x_times]
                     df = pd.DataFrame(
                         {"year": years, "month": months, "day": days, "hour": hours}
-                    )
+                    ).astype("int")
                     df["path"] = x
                     self_times.append(df)
             else:
@@ -297,7 +286,6 @@ def operation(self, method="mul", ff=None, var=None):
         raise ValueError("Unable to carry out operation given times in datasets!")
 
     if new is False:
-
         # make sure the ff file is not removed from safe list in subsequent
         # actions prior to running
         if (ff is not None) and (session_info["lazy"]):
@@ -305,9 +293,7 @@ def operation(self, method="mul", ff=None, var=None):
             self._safe.append(ff)
 
         if len(self.history) == len(self._hold_history):
-
             for x in self:
-
                 # check that the datasets can actually be worked with
                 if var is None:
                     if (len(nc_variables(ff)) != len(nc_variables(x))) and (
@@ -320,7 +306,6 @@ def operation(self, method="mul", ff=None, var=None):
             prior_command = ""
 
         else:
-
             prior_command = self.history[-1].replace("cdo ", " ").replace("  ", " ")
 
         # we need to make sure you can chain multiple adds etc.#
@@ -342,12 +327,10 @@ def operation(self, method="mul", ff=None, var=None):
         # run the command if not lazy
 
         if session_info["lazy"] is False:
-
             new_files = []
             new_commands = []
 
             for FF in self:
-
                 target = temp_file(".nc")
                 the_command = cdo_command.replace("infile09178", FF) + " " + target
                 the_command = tidy_command(the_command)
@@ -379,7 +362,8 @@ def operation(self, method="mul", ff=None, var=None):
 
 def multiply(self, x=None, var=None):
     """
-    Multiply a dataset
+    multiply: Multiply a dataset.
+
     This will multiply a dataset by a constant, another dataset or a netCDF file.
 
     Parameters
@@ -398,10 +382,18 @@ def multiply(self, x=None, var=None):
 
     >>> ds.multiply(10)
 
+    Or, you could use standard python multiplication syntax:
+
+    >>> ds * 10
+
     To multiply the values in a dataset by the values of variables in dataset ds2, you would do the following:
 
     >>> ds1.multiply(ds2)
 
+    Or, you could use standard python multiplication syntax:
+
+    >>> ds1 * ds2
+
     Grids in the datasets must match. Multiplication will occur in matching timesteps in ds1 and ds2. If there is only 1 timestep in ds2, then
     the data from that timestep in ds2 will multiply the data in all timesteps in ds1.
 
@@ -431,11 +423,13 @@ def multiply(self, x=None, var=None):
 
     operation(self=self, method="mul", ff=ff, var=var)
 
+
 __mul__ = multiply
 
+
 def rmse(self, x=None):
     """
-    Calculate the root-mean-square-error of two datasets 
+    rmse: Calculate the root-mean-square-error of two datasets
 
     Parameters
     ------------
@@ -465,13 +459,13 @@ def rmse(self, x=None):
     ds1 = self.copy()
     # subtract the data in one dataset from the other
     ds1.subtract(ds2)
-    #square the differences
+    # square the differences
     ds1.power(2)
     # sum up over all time steps
     ds1.tsum()
     # divide by the number of time steps
     ds1.divide(n_times)
-    #square the results
+    # square the results
     ds1.sqrt()
     ds1.run()
 
@@ -480,11 +474,10 @@ def rmse(self, x=None):
     self._hold_history = ds1._hold_history
 
 
-
-
 def subtract(self, x=None, var=None):
     """
-    Subtract from a dataset
+    subtract: Subtract from a dataset.
+
     This will subtract a constant, another dataset or a netCDF file from the dataset.
 
     Parameters
@@ -503,16 +496,21 @@ def subtract(self, x=None, var=None):
 
     >>> ds.subtract(10)
 
+    Or, you could use standard python subtraction syntax:
+
+    >>> ds - 10
+
     To substract the values in a dataset ds2 from those in a dataset ds1, you would do the following:
 
     >>> ds1.subtract(ds2)
 
+    Or, you could use standard python subtraction syntax:
+
+    >>> ds1 - ds2
+
     Grids in the datasets must match. Division will occur in matching timesteps in ds1 and ds2 if there are matching timesteps. If there is only 1 timestep in ds2, then
     the data from that timestep in ds2 will be subtracted from the data in all timesteps in ds1.
 
-    Subtracting of the data from another netCDF file will work in the same way:
-
-    >>> ds1.subtract("example.nc")
     """
 
     # 1: int, float subtraction
@@ -536,12 +534,14 @@ def subtract(self, x=None, var=None):
 
     operation(self=self, method="sub", ff=ff, var=var)
 
+
 __sub__ = subtract
 
 
 def add(self, x=None, var=None):
     """
-    Add to a dataset
+    add: Add to a dataset
+
     This will add a constant, another dataset or a netCDF file to the dataset.
     nctoolkit will automatically determine the appropriate comparison required.
 
@@ -554,17 +554,25 @@ def add(self, x=None, var=None):
     var: str
         A variable in the x to use for the operation
 
-      Examples
+    Examples
     ------------
 
     If you wanted to add 10 to all variables in a dataset, you would do the following:
 
     >>> ds.add(10)
 
+    Or, you could use standard python addition syntax:
+
+    >>> ds + 10
+
     To add the values in a dataset ds2 from a dataset ds1, you would do the following:
 
     >>> ds1.add(ds2)
 
+    Or, you could use standard python addition syntax:
+
+    >>> ds1 + ds2
+
     Grids in the datasets must match. Addition will occur in matching timesteps in ds1 and ds2. If there is only 1 timestep in ds2, then
     the data from that timestep will be added to the data in all ds1 time steps.
 
@@ -572,7 +580,6 @@ def add(self, x=None, var=None):
 
     >>> ds1.add("example.nc")
 
-
     """
 
     # 1: int, float addition
@@ -596,12 +603,14 @@ def add(self, x=None, var=None):
 
     operation(self=self, method="add", ff=ff, var=var)
 
+
 __add__ = add
 
 
 def divide(self, x=None, var=None):
     """
-    Divide the data
+    divide: Divide the data.
+
     This will divide the dataset by a constant, another dataset or a netCDF file.
 
     Parameters
@@ -616,20 +625,25 @@ def divide(self, x=None, var=None):
     Examples
     ------------
 
-    If you wanted to dividie all variables in a dataset by 20, you would do the following:
+    If you wanted to divide all variables in a dataset by 20, you would do the following:
 
     >>> ds.divide(10)
 
+    Or, you could use standard python division syntax:
+
+    >>> ds / 10
+
     To divide values in a dataset by those in the dataset ds2 from a dataset ds1, you would do the following:
 
     >>> ds1.divide(ds2)
 
+    Or, you could use standard python division syntax:
+
+    >>> ds1 / ds2
+
     Grids in the datasets must match. Division will occur in matching timesteps in ds1 and ds2. If there is only 1 timestep in ds2, then
     the data from that timestep in ds2 will divided the data in all ds1 time steps.
 
-    Adding the data from another netCDF file will work in the same way:
-
-    >>> ds.divide("example.nc")
     """
 
     # 1: int, float division
@@ -653,12 +667,13 @@ def divide(self, x=None, var=None):
 
     operation(self=self, method="div", ff=ff, var=var)
 
+
 __truediv__ = divide
 
 
 def abs(self):
     """
-    Method to get the absolute value of variables
+    abs: Method to get the absolute value of variables
 
     Examples
     ------------
@@ -668,14 +683,14 @@ def abs(self):
     >>> ds.abs()
 
     """
-    cdo_command = f"cdo -abs"
+    cdo_command = "-abs"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def power(self, x=None):
     """
-    Powers of variables in dataset
+    power: Powers of variables in dataset
 
     Parameters
     ------------
@@ -694,16 +709,17 @@ def power(self, x=None):
     if not isinstance(x, (int, float)):
         raise TypeError("x is not a float or int")
 
-    cdo_command = f"cdo -pow,{x}"
+    cdo_command = f"-pow,{x}"
+
+    self.cdo_command(cdo_command)
 
-    run_this(cdo_command, self, output="ensemble")
 
 __pow__ = power
 
 
 def exp(self):
     """
-    Method to get the exponential of variables
+    exp: Method to get the exponential of variables
 
     Examples
     ------------
@@ -713,14 +729,14 @@ def exp(self):
     >>> ds.exp(0.5)
 
     """
-    cdo_command = f"cdo -exp"
+    cdo_command = "-exp"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command)
 
 
 def log(self):
     """
-    Method to get the natural log of variables
+    log: Method to get the natural log, ln, of variables
 
     Examples
     ------------
@@ -730,14 +746,14 @@ def log(self):
     >>> ds.log()
 
     """
-    cdo_command = f"cdo -ln"
+    cdo_command = "-ln"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command)
 
 
 def log10(self):
     """
-    Method to get the base 10 log of variables
+    log10: Method to get the base 10 log, log10, of variables
 
     Examples
     ------------
@@ -747,31 +763,31 @@ def log10(self):
     >>> ds.log10()
 
     """
-    cdo_command = f"cdo -log10"
+    cdo_command = "-log10"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command)
 
 
 def square(self):
     """
-    Method to get the square of variables
+    square: Method to get the square of variables
 
     Examples
     ------------
 
     If you wanted to calculate the square of each variable, you just need to do this:
 
-    >>> ds.power()
+    >>> ds.square()
 
     """
-    cdo_command = f"cdo -sqr"
+    cdo_command = "-sqr"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command)
 
 
 def sqrt(self):
     """
-    Method to get the square root of variables
+    sqrt: Method to get the square root of variables
 
     Examples
     ------------
@@ -781,8 +797,6 @@ def sqrt(self):
     >>> ds.sqrt()
 
     """
-    cdo_command = f"cdo -sqrt"
-
-    run_this(cdo_command, self, output="ensemble")
-
+    cdo_command = "-sqrt"
 
+    self.cdo_command(cdo_command)
