@@ -3,7 +3,6 @@ import dill
 import inspect
 import numpy as np
 
-from nctoolkit.runthis import run_this
 from nctoolkit.session import session_info
 from nctoolkit.utils import version_below
 
@@ -97,7 +96,7 @@ funs = [
     "int",
     "float",
     "log10",
-    "thickness"
+    "thickness",
 ]
 
 translation = dict()
@@ -106,7 +105,7 @@ for ff in funs:
         translation[ff] = ff
 
 translation["int"] = "int"
-#translation["deltaz"] = "cdeltaz"
+# translation["deltaz"] = "cdeltaz"
 translation["float"] = "float"
 
 translation["arcsin"] = "asin"
@@ -154,6 +153,7 @@ translation["lat"] = "clat"
 translation["longitude"] = "clon"
 translation["latitude"] = "clat"
 
+
 # split using all possible mathematical operators
 def split1(mystr):
     return re.split("([+-/*()<>=])", mystr)
@@ -169,24 +169,38 @@ pattern = re.compile(":\w*")
 
 def assign(self, drop=False, **kwargs):
     """
-    Create new variables
+    assign: Create new variables using mathematical operations on existing variables.
+
     Existing columns that are re-assigned will be overwritten.
+    This method operators in a similar fashion to the pandas assign method.
 
     Parameters
     ----------
     drop : bool
         Set to True if you want existing variables to be removed once the new ones have been created.
         Defaults to False.
-
-        should evaluate to a numeric. New variables are calculated for each grid cell and time step.
     **kwargs : dict of {str: callable}
-        New variable names are keywords. All terms in the equation given by the lamda function
+        New variable names are keywords. All terms in the equation given by the lambda function
         should evaluate to a numeric. New variables are calculated for each grid cell and time step.
     Notes
     -----
     Operations are carried out in the order give. So if a new variable is created in the first argument,
     it can then be used in following arguments.
 
+    Examples
+    --------
+
+    Temperature could be converted from Celsius to Kelvin by:
+
+    >>> ds.assign(temperature_K=lambda x: x.temperature + 273.15)
+
+    Temperatures higher than the spatial average temperature could be found by:
+
+    >>> ds.assign(hot=lambda x: x.temperature > spatial_mean(x.temperature)))
+
+
+
+
 
 
 
@@ -227,7 +241,6 @@ def assign(self, drop=False, **kwargs):
         except:
             start = dill.source.getsource(start).replace("\n", "").strip()
     except:
-
         if interactive:
             import readline
 
@@ -332,7 +345,6 @@ def assign(self, drop=False, **kwargs):
     starts = ("; ").join(starts)
 
     for start in starts.split(";"):
-
         patternl = re.compile("lambda \w*:")
         lambda_value = patternl.findall(start)[0][-2]
 
@@ -387,7 +399,6 @@ def assign(self, drop=False, **kwargs):
         fun_pattern = re.compile("[a-zA-Z\_][a-zA-Z\_z.0-9]*\(")
 
         for x in fun_pattern.findall(start):
-
             check = True
             while check:
                 x_terms = re.finditer(x.replace("(", "\\(").replace("[", "\\["), start)
@@ -435,7 +446,6 @@ def assign(self, drop=False, **kwargs):
         for x in terms:
             if ("[" in x and f"{lambda_value}." in x) is False:
                 if fun_pattern.search(x) is not None:
-
                     fix = True
                     n = 0
                     n_limit = start.count("x")
@@ -489,10 +499,8 @@ def assign(self, drop=False, **kwargs):
                         # need to tweak this so that it captures the output and returns an appropriate error
                         new_x = eval(x, globals(), frame.f_back.f_locals)
                         if isinstance(new_x, str):
-                            error_message = f"{x} evaluates to a string!"
                             raise ValueError(f"{x} evaluates to a string")
                         if is_number(str(new_x)) is False:
-                            error_message = f"{x} does not evaluate to numeric!"
                             raise ValueError(f"{x} does not evaluate to numeric!")
 
                         new_start = ""
@@ -505,7 +513,6 @@ def assign(self, drop=False, **kwargs):
                         error_message = None
 
                     except:
-
                         if x_fun in translation.keys():
                             x_term = between_brackets(x)
                             if (f"{lambda_value}." in x_term) is False:
@@ -671,7 +678,6 @@ def assign(self, drop=False, **kwargs):
             return re.split("([+-/*()&|<>=!^])", mystr)
 
         for tt in start.split(";"):
-
             tt_frag = []
             l_pattern = re.compile("lambda (\w*):")
             l_string = l_pattern.findall(tt)[0]
@@ -694,12 +700,6 @@ def assign(self, drop=False, **kwargs):
 
         start = start.replace(" lambda ", " ").replace(" ", "")
 
-        version = session_info["cdo"]
-        if version_below(version, "1.9.8"):
-            if "isnan(" in start:
-                raise ValueError(
-                    "Please install version >=1.9.8 of CDO to access isnan"
-                )
         # We need to fix pow functions potentially. Though, it might be better to stick with ^
 
         # translate numpy style functions to cdo functions
@@ -730,7 +730,6 @@ def assign(self, drop=False, **kwargs):
     command = " ".join(split_this(command)).replace(" . ", ".").replace(";", " ; ")
 
     for term in command.split(" "):
-
         if "." in term:
             pattern1 = re.compile(r"[a-zA-Z]")
             if len(pattern1.findall(term)) > 0 and "^" not in term:
@@ -759,8 +758,8 @@ def assign(self, drop=False, **kwargs):
 
     # create the cdo call and run it
     if drop is False:
-        cdo_command = f"cdo -aexpr,'{command}'"
+        cdo_command = f"-aexpr,'{command}'"
     else:
-        cdo_command = f"cdo -expr,'{command}'"
+        cdo_command = f"-expr,'{command}'"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
