@@ -8,7 +8,6 @@ from nctoolkit.session import remove_safe, get_safe
 
 
 def cor(self, var1=None, var2=None, method="fld"):
-
     if len(self) == 0:
         raise ValueError("Failure due to empty dataset!")
 
@@ -36,27 +35,27 @@ def cor(self, var1=None, var2=None, method="fld"):
 
     if var1 != var2:
         contents = self.contents
-        df = contents.query("variable in [@var1, @var2]").loc[:,["variable", "data_type"]]
+        df = contents.query("variable in [@var1, @var2]").loc[
+            :, ["variable", "data_type"]
+        ]
         # if
         if len([x for x in df.index if "file" in str(x)]) == 0:
             df.index = ["file" for x in range(len(df.index))]
         df = (
-            df
-            .pivot(values = "data_type", columns = "variable")
-            .rename(columns = {var1:"var1"})
-            .rename(columns = {var2:"var2"})
+            df.pivot(values="data_type", columns="variable")
+            .rename(columns={var1: "var1"})
+            .rename(columns={var2: "var2"})
         )
         if len(df.query("var1 != var2")) > 0:
-            raise ValueError(f"{var1} and {var2} have different data types. Please select data type with set_precision. Suggestion: F32.")
-
-
+            raise ValueError(
+                f"{var1} and {var2} have different data types. Please select data type with set_precision. Suggestion: F32."
+            )
 
     # Calculate the correlations in each file
     new_files = []
     new_commands = []
 
     for ff in self:
-
         # create the temp file for targeting
         target = temp_file(".nc")
 
@@ -92,10 +91,13 @@ def cor(self, var1=None, var2=None, method="fld"):
 
 def cor_space(self, var1=None, var2=None):
     """
-    Calculate the correlation correct between two variables in space
+    cor_space: Calculate the correlation correct between two variables in space.
+
     This is calculated for each time step. The correlation coefficient coefficient is
     calculated using values in all grid cells, ignoring missing values.
 
+    This calculates the Pearson correlation coefficient.
+
     Parameters
     -------------
     var1: str
@@ -120,8 +122,10 @@ def cor_space(self, var1=None, var2=None):
 
 def cor_time(self, var1=None, var2=None):
     """
-    Calculate the correlation correct in time between two variables
+    cor_time: Calculate the correlation correct in time between two variables
+
     The correlation is calculated for each grid cell, ignoring missing values.
+    This calculates the Pearson correlation coefficient.
 
     Parameters
     -------------
@@ -135,7 +139,7 @@ def cor_time(self, var1=None, var2=None):
 
     If you wanted to calculate the temporal correlation coefficient between variables x and y in a dataset, you would do this:
 
-    >>> ds.cor_space("x", "y")
+    >>> ds.cor_time("x", "y")
 
     The correlation coefficient will be calculated for each grid cell.  This method will indicate how temporally correlated variables are
     in different spatial regions.
