@@ -6,7 +6,7 @@ import os
 
 def create_ensemble(path="", recursive=True):
     """
-    Generate an ensemble
+    create_ensemble: Generate an ensemble of files from a directory.
 
     Parameters
     -------------
@@ -18,8 +18,8 @@ def create_ensemble(path="", recursive=True):
 
     Returns
     -------------
-    list
-        A list of files
+
+    files : list of files
 
     Examples
     ------------
