@@ -5,14 +5,14 @@ import numbers
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.runthis import run_this, run_nco, tidy_command
+from nctoolkit.runthis import run_nco, tidy_command
 from nctoolkit.temp_file import temp_file
 from nctoolkit.session import remove_safe
 
 
 def crop(self, lon=[-180, 180], lat=[-90, 90], nco=False, nco_vars=None):
     """
-    Crop to a rectangular longitude and latitude box
+    crop: Crop to a rectangular longitude and latitude box
 
     Parameters
     -------------
@@ -56,7 +56,7 @@ def crop(self, lon=[-180, 180], lat=[-90, 90], nco=False, nco_vars=None):
         nco_vars = [nco_vars]
 
     # check validity of lon/lat supplied
-    if not isinstance(lon, list) or  not isinstance(lat, list):
+    if not isinstance(lon, list) or not isinstance(lat, list):
         raise TypeError("Check that lon/lat ranges are tuples")
 
     if len(lon) != 2:
@@ -85,10 +85,10 @@ def crop(self, lon=[-180, 180], lat=[-90, 90], nco=False, nco_vars=None):
     if nco is False:
         if (lon[0] >= -180) and (lon[1] <= 180) and (lat[0] >= -90) and (lat[1] <= 90):
             lat_box = str_flatten(lon + lat)
-            cdo_command = "cdo -sellonlatbox," + lat_box
+            cdo_command = "-sellonlatbox," + lat_box
             cdo_command = tidy_command(cdo_command)
 
-            run_this(cdo_command, self, output="ensemble")
+            self.cdo_command(cdo_command, ensemble=False)
             return None
         else:
             raise ValueError("The lonlat box supplied is not valid!")
@@ -97,11 +97,9 @@ def crop(self, lon=[-180, 180], lat=[-90, 90], nco=False, nco_vars=None):
     new_commands = []
 
     for ff in self:
-
         # find the names of lonlat
 
         if nco_vars is not None:
-
             var_str = f" -v {str_flatten(nco_vars)}"
         else:
             var_str = " "
