@@ -1,7 +1,7 @@
 import copy
 
 from nctoolkit.cleanup import cleanup
-from nctoolkit.runthis import run_this, run_cdo, tidy_command
+from nctoolkit.runthis import run_cdo, tidy_command
 from nctoolkit.temp_file import temp_file
 from nctoolkit.session import remove_safe
 
@@ -9,7 +9,6 @@ from nctoolkit.session import remove_safe
 def boxstat(self, stat="mean", x=1, y=1):
     """Method to calculate the spatial stat from a dataset"""
 
-
     if not isinstance(x, int):
         raise ValueError("x should be int")
     if not isinstance(y, int):
@@ -23,14 +22,15 @@ def boxstat(self, stat="mean", x=1, y=1):
     if len(self) == 0:
         raise ValueError("Failure due to empty dataset!")
 
-    cdo_command = f"cdo -gridbox{stat},{x},{y}"
+    cdo_command = f"-gridbox{stat},{x},{y}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def box_mean(self, x=1, y=1):
     """
-    Calculate the grid box mean for all variables
+    box_mean: Calculate the grid box mean for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -40,6 +40,12 @@ def box_mean(self, x=1, y=1):
     y: int or float
         Number of boxes in the y, e.g. north-south direction
 
+    Examples
+    ------------
+    If you want to calculate the mean in each 4 by 4 box:
+
+    >>> ds.box_mean(x=4, y=4)
+
     """
 
     boxstat(self, stat="mean", x=x, y=y)
@@ -47,7 +53,8 @@ def box_mean(self, x=1, y=1):
 
 def box_max(self, x=1, y=1):
     """
-    Calculate the grid box max for all variables
+    box_max: Calculate the grid box max for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -57,6 +64,13 @@ def box_max(self, x=1, y=1):
     y: int or float
         Number of boxes in the y, e.g. north-south direction
 
+
+    Examples
+    ------------
+    If you want to calculate the max in each 4 by 4 box:
+
+    >>> ds.box_max(x=4, y=4)
+
     """
 
     boxstat(self, stat="max", x=x, y=y)
@@ -64,7 +78,8 @@ def box_max(self, x=1, y=1):
 
 def box_min(self, x=1, y=1):
     """
-    Calculate the grid box min for all variables
+    box_min: Calculate the grid box min for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -74,6 +89,12 @@ def box_min(self, x=1, y=1):
     y: int or float
         Number of boxes in the y, e.g. north-south direction
 
+    Examples
+    ------------
+    If you want to calculate the min in each 4 by 4 box:
+
+    >>> ds.box_min(x=4, y=4)
+
     """
 
     boxstat(self, stat="min", x=x, y=y)
@@ -81,7 +102,8 @@ def box_min(self, x=1, y=1):
 
 def box_sum(self, x=1, y=1):
     """
-    Calculate the grid box sum for all variables
+    box_sum: Calculate the grid box sum for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -91,6 +113,13 @@ def box_sum(self, x=1, y=1):
     y: int or float
         Number of boxes in the y, e.g. north-south direction
 
+    Examples
+    ------------
+
+    If you want to calculate the sum in each 4 by 4 box:
+
+    >>> ds.box_sum(x=4, y=4)
+
     """
 
     boxstat(self, stat="sum", x=x, y=y)
@@ -98,7 +127,8 @@ def box_sum(self, x=1, y=1):
 
 def box_range(self, x=1, y=1):
     """
-    Calculate the grid box range for all variables
+    box_range: Calculate the grid box range for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -108,6 +138,13 @@ def box_range(self, x=1, y=1):
     y: int or float
         Number of boxes in the y, e.g. north-south direction
 
+    Examples
+    ------------
+    If you want to calculate the range in each 4 by 4 box:
+
+    >>> ds.box_range(x=4, y=4)
+
+
     """
 
     boxstat(self, stat="range", x=x, y=y)
@@ -119,14 +156,15 @@ def fldstat(self, stat="mean"):
     if len(self) == 0:
         raise ValueError("Failure due to empty dataset!")
 
-    cdo_command = f"cdo -fld{stat}"
+    cdo_command = f"-fld{stat}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def spatial_mean(self):
     """
-    Calculate the area weighted spatial mean for all variables
+    spatial_mean: Calculate the area weighted spatial mean for all variables.
+
     This is performed for each time step.
 
     Examples
@@ -136,7 +174,9 @@ def spatial_mean(self):
 
     >>> ds.spatial_mean()
 
-    Note that this calculation will calculate the average using weights based on each cell's
+    Note
+    ------
+    This method will calculate the average using weights based on each cell's
     area. If cell areas cannot be calculated, it will take a straight average, and a warning
     will say this.
 
@@ -146,7 +186,8 @@ def spatial_mean(self):
 
 def spatial_min(self):
     """
-    Calculate the spatial minimum for all variables
+    spatial_min: Calculate the spatial minimum for all variables.
+
     This is performed for each time step.
 
     Examples
@@ -162,7 +203,8 @@ def spatial_min(self):
 
 def spatial_max(self):
     """
-    Calculate the spatial maximum for all variables
+    spatial_max: Calculate the spatial maximum for all variables.
+
     This is performed for each time step.
 
     Examples
@@ -177,35 +219,40 @@ def spatial_max(self):
 
 def spatial_stdev(self):
     """
-    Calculate the spatial range for all variables
+    spatial_stdev: Calculate the spatial standard deviation for all variables.
+
     This is performed for each time step.
 
     Examples
     ------------
-    If you want to calculate the range of each variable across space for a dataset, just do the following:
+    If you want to calculate the spatial standard deviation for a dataset, just do the following:
 
-    >>> ds.spatial_max()
+    >>> ds.spatial_stdev()
     """
     fldstat(self, stat="std")
 
 
 def spatial_var(self):
     """
-    Calculate the spatial range for all variables
+    spatial_var: Calculate the spatial variance for all variables.
+
     This is performed for each time step.
 
     Examples
     ------------
-    If you want to calculate the range of each variable across space for a dataset, just do the following:
+    If you want to calculate the spatial variance for a dataset, just do the following:
+
+    >>> ds.spatial_var()
+
 
-    >>> ds.spatial_max()
     """
     fldstat(self, stat="var")
 
 
 def spatial_range(self):
     """
-    Calculate the spatial range for all variables
+    spatial_range: Calculate the spatial range for all variables.
+
     This is performed for each time step.
 
     Examples
@@ -219,7 +266,8 @@ def spatial_range(self):
 
 def spatial_sum(self, by_area=False):
     """
-    Calculate the spatial sum for all variables
+    spatial_sum: Calculate the spatial sum for all variables.
+
     This is performed for each time step.
 
     Parameters
@@ -253,22 +301,22 @@ def spatial_sum(self, by_area=False):
         raise TypeError("by_area is not boolean")
 
     if len(self) == 1 or (by_area is False):
-
         if by_area:
             self.run()
 
-            cdo_command = f"cdo -fldsum -mul {self.current[0]} -gridarea "
+            cdo_command = f"-fldsum -mul {self.current[0]} -gridarea "
         else:
-            cdo_command = "cdo -fldsum"
+            cdo_command = "-fldsum"
 
-        run_this(cdo_command, self, output="ensemble")
+        self.cdo_command(cdo_command, ensemble=False)
+
+        # run_this(cdo_command, self, output="ensemble")
 
         return None
 
     new_files = []
     new_commands = []
     for ff in self:
-
         target = temp_file("nc")
 
         cdo_command = f"cdo -fldsum -mul {ff} -gridarea {ff} {target}"
@@ -291,7 +339,8 @@ def spatial_sum(self, by_area=False):
 
 def spatial_percentile(self, p=None):
     """
-    Calculate the spatial sum for all variables
+    spatial_percentile: Calculate the spatial percentile for all variables
+
     This is performed for each time step.
 
     Parameters
@@ -317,6 +366,6 @@ def spatial_percentile(self, p=None):
     if (p < 0) or (p > 100):
         raise ValueError(f"p: {str(p)} is not between 0 and 100!")
 
-    cdo_command = f"cdo -fldpctl,{str(p)}"
+    cdo_command = f"-fldpctl,{str(p)}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
