@@ -1,11 +1,6 @@
-from nctoolkit.runthis import run_this
-
-# to do. Some padding needs to be added in case something like 2000/1/1 is provided.
-
-
 def time_interp(self, start=None, end=None, resolution="monthly"):
     """
-    Temporally interpolate variables based on date range and time resolution
+    time_interp: Temporally interpolate variables based on date range and time resolution
 
     Parameters
     -------------
@@ -18,6 +13,21 @@ def time_interp(self, start=None, end=None, resolution="monthly"):
     resolution : str
         Time steps used for interpolation. Needs to be "daily", "weekly", "monthly"
         or "yearly". Defaults to monthly.
+
+    Examples
+    -------------
+    Interpolate from 01/01/2000 to 01/01/2001 to monthly data:
+
+    >>> ds.time_interp(start="2000/01/01", end="2001/01/01", resolution="monthly")
+
+    Interpolate from 01/01/2000 to 01/01/2001 to daily data:
+
+    >>> ds.time_interp(start="2000/01/01", end="2001/01/01", resolution="daily")
+
+    Interpolate from 01/01/2000 to 01/01/2001 to weekly data:
+
+    >>> ds.time_interp(start="2000/01/01", end="2001/01/01", resolution="weekly")
+
     """
 
     if resolution not in ["daily", "weekly", "monthly", "yearly"]:
@@ -43,17 +53,17 @@ def time_interp(self, start=None, end=None, resolution="monthly"):
     cdo_command = f"-inttime,{start},12:00:00,{resolution}"
 
     if end is None:
-        cdo_command = f"cdo {cdo_command}"
+        cdo_command = f"{cdo_command}"
     else:
         end = end.replace("/", "-")
-        cdo_command = f"cdo -seldate,{start},{end} {cdo_command}"
+        cdo_command = f"-seldate,{start},{end} {cdo_command}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def timestep_interp(self, steps=None):
     """
-    Temporally interpolate a dataset to given number of time steps
+    timestep_interp: Temporally interpolate a dataset to given number of time steps
     between existing time steps
 
     Parameters
@@ -61,6 +71,13 @@ def timestep_interp(self, steps=None):
     steps : int
         Number of time steps to interpolate between existing time steps. For example,
         if you wanted to go from daily to hourly data you would set steps=24.
+
+    Examples
+    -------------
+    Interpolate from daily to hourly data:
+
+    >>> ds.timestep_interp(steps=24)
+
     """
 
     if not isinstance(steps, int):
@@ -69,6 +86,6 @@ def timestep_interp(self, steps=None):
     if steps < 2:
         raise ValueError(f"{steps} is not greater than 1")
 
-    cdo_command = f"cdo -intntime,{steps}"
+    cdo_command = f"-intntime,{steps}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
