@@ -1,4 +1,3 @@
-from nctoolkit.runthis import run_this
 from nctoolkit.utils import is_curvilinear
 
 
@@ -9,14 +8,15 @@ def zonstat(self, stat="mean"):
             raise TypeError(
                 f"meridonal_{stat} cannot be calculated for curvilinear grids."
             )
-    cdo_command = f"cdo -mer{stat}"
+    cdo_command = f"-mer{stat}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def meridonial_mean(self):
     """
-    Calculate the meridonial mean for each year/month combination in files.
+    meridonial_mean: Calculate the meridonial mean for each year/month combination in files.
+
     This applies to each file in an ensemble.
 
     Examples
@@ -30,7 +30,8 @@ def meridonial_mean(self):
 
 def meridonial_min(self):
     """
-    Calculate the meridonial minimum for each year/month combination in files.
+    meridonial_min: Calculate the meridonial minimum for each year/month combination in files.
+
     This applies to each file in an ensemble.
 
     Examples
@@ -44,7 +45,8 @@ def meridonial_min(self):
 
 def meridonial_max(self):
     """
-    Calculate the meridonial maximum for each year/month combination in files.
+    meridonial_max: Calculate the meridonial maximum for each year/month combination in files.
+
     This applies to each file in an ensemble.
 
     Examples
@@ -59,7 +61,8 @@ def meridonial_max(self):
 
 def meridonial_range(self):
     """
-    Calculate the meridonial range for each year/month combination in files.
+    meridonial_range: Calculate the meridonial range for each year/month combination in files.
+
     This applies to each file in an ensemble.
 
     Examples
