@@ -1,5 +1,7 @@
 import copy
 import multiprocessing
+import platform
+import warnings
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
@@ -20,12 +22,25 @@ def nco_command(self, command=None, ensemble=False):
     ensemble : boolean
         Set to True if you want the command to take all of the files as input.
         This is useful for ensemble methods.
+
+    Examples
+    -------------
+    Select a variable from a file
+    >>> ds.nco_command("ncks -v tas")
     """
 
     self.run()
 
+    if len(self) == 1:
+        ensemble = False
+
     cores = session_info["cores"]
 
+    if platform.system() != "Linux":
+        if cores > 1:
+            warnings.warn("This cannot run in parallel on macOS")
+            cores = 1
+
     # First, check that the command is valid
     if command is None:
         raise ValueError("Please supply a command")
@@ -46,7 +61,7 @@ def nco_command(self, command=None, ensemble=False):
     new_files = []
     new_commands = []
 
-    if cores >= 1:
+    if cores > 1:
         pool = multiprocessing.Pool(cores)
         target_list = []
         results = dict()
@@ -54,15 +69,14 @@ def nco_command(self, command=None, ensemble=False):
         target_list = []
 
     if (ensemble is False) or (len(self) == 1):
-
         if cores > 1:
             for ff in self:
-
                 target = temp_file(".nc")
 
                 append_safe(target)
 
                 the_command = f"{command} {ff} {target}"
+                the_command = the_command.replace("  ", " ")
 
                 temp = pool.apply_async(run_nco, [the_command, target])
                 results[ff] = temp
@@ -70,11 +84,11 @@ def nco_command(self, command=None, ensemble=False):
 
         else:
             for ff in self:
-
                 target = temp_file(".nc")
                 append_safe(target)
 
                 the_command = f"{command} {ff} {target}"
+                the_command = the_command.replace("  ", " ")
 
                 target = run_nco(the_command, target=target)
 
@@ -88,6 +102,7 @@ def nco_command(self, command=None, ensemble=False):
         files = str_flatten(self.current, " ")
 
         the_command = f"{command} {files} {target}"
+        the_command = the_command.replace("  ", " ")
 
         target = run_nco(the_command, target=target)
 
@@ -95,7 +110,6 @@ def nco_command(self, command=None, ensemble=False):
         new_commands.append(the_command)
 
     if cores == 1 or ensemble:
-
         self.current = new_files
 
         while True:
@@ -103,14 +117,16 @@ def nco_command(self, command=None, ensemble=False):
             for ff in new_files:
                 if len([x for x in get_safe() if x == ff]) > 1:
                     remove_safe(ff)
-                    removed +=1
+                    removed += 1
             if removed == 0:
                 break
 
-        self.history.append(command)
+        for cc in new_commands:
+            self.history.append(cc)
+        # self.history.append(command)
         self._hold_history = copy.deepcopy(self.history)
 
-    if cores > 1:
+    if cores > 1 and ensemble is False:
         pool.close()
         pool.close()
         for k, v in results.items():
@@ -123,10 +139,10 @@ def nco_command(self, command=None, ensemble=False):
 
         while True:
             removed = 0
-            for ff in new_files:
+            for ff in target_list:
                 if len([x for x in get_safe() if x == ff]) > 1:
                     remove_safe(ff)
-                    removed +=1
+                    removed += 1
             if removed == 0:
                 break
 
