@@ -1,13 +1,12 @@
 import os
 
 from nctoolkit.api import open_data
-from nctoolkit.runthis import run_this
 import nctoolkit.api as api
 
 
 def reduce_grid(self, mask=None):
     """
-    Reduce the dataset to non-zero locations in a mask
+    reduce_grid: Reduce the dataset to non-zero locations in a mask
 
     Parameters
     -------------
@@ -35,7 +34,7 @@ def reduce_grid(self, mask=None):
     targeted_mask.cdo_command("-setmisstoc,0")
     targeted_mask.run()
 
-    cdo_command = f"cdo -reducegrid,{targeted_mask.current[0]}"
+    cdo_command = f"-reducegrid,{targeted_mask.current[0]}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
     self.run()
