@@ -7,11 +7,12 @@ import warnings
 from nctoolkit.api import open_data
 from nctoolkit.cleanup import cleanup
 from nctoolkit.generate_grid import generate_grid
-from nctoolkit.runthis import run_this, run_cdo
+from nctoolkit.runthis import run_cdo, run_this
 from nctoolkit.session import append_safe, remove_safe, get_safe
 from nctoolkit.temp_file import temp_file
 import nctoolkit.api as api
 
+
 def is_iterable(x):
     try:
         iter(x)
@@ -20,9 +21,11 @@ def is_iterable(x):
         return False
 
 
-def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwargs):
+def regrid(self, grid=None, method="bil", recycle=False, one_grid=False, **kwargs):
     """
-    Regrid a dataset to a target grid
+    regrid: Regrid a dataset to a target grid
+
+    Horizontal interpolation
 
     Parameters
     -------------
@@ -38,15 +41,34 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
         First order conservative remapping - "con"
         Second order conservative remapping - "con2"
         Large area fraction remapping - "laf"
-    recycle : bool 
-        Set to True if you want to re-use the remapping weights when you are regridding another dataset. 
-    one_grid : bool 
-        Set to True if all files in multi-file dataset have the same grid, to speed things up. 
-    kwargs : optional method to generate grid 
+    recycle : bool
+        Set to True if you want to re-use the remapping weights when you are regridding another dataset.
+    one_grid : bool
+        Set to True if all files in multi-file dataset have the same grid, to speed things up.
+    kwargs : optional method to generate grid
         Instead of supplying a grid using 'grid', you can supply `lon` and `lat`. These must be equally
         lengthed lists or arrays that will be used to generate the grid. If you want to regrid to a single
         location you can just supply a float to lon and lat.
-        
+
+    Examples
+    -------------
+    Regrid to a grid defined by a pandas data frame:
+
+    >>> ds.regrid(grid=grid_df)
+
+    Regrid to a grid defined by a netCDF file:
+
+    >>> ds.regrid(grid="grid.nc")
+
+    Regrid to a grid defined by a nctoolkit.DataSet:
+
+    >>> ds.regrid(grid=grid_ds)
+
+    Regrid to a grid defined by a pandas data frame using nearest neighbour:
+
+    >>> ds.regrid(grid=grid_df, method="nn")
+
+
     """
 
     if grid is None and len(kwargs) > 0:
@@ -61,7 +83,7 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
                 lat = [lat]
 
             if len(lon) == len(lat):
-                grid = pd.DataFrame({"lon":lon, "lat":lat})
+                grid = pd.DataFrame({"lon": lon, "lat": lat})
 
     if len(self) == 0:
         raise ValueError("Failure due to empty dataset!")
@@ -78,8 +100,9 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
         if grid._weights is not None and grid._grid is not None:
             target_grid = grid._grid
             weights_nc = grid._weights
-            cdo_command = f"cdo -remap,{target_grid},{weights_nc}"
-            run_this(cdo_command, self, output="ensemble")
+            cdo_command = f"-remap,{target_grid},{weights_nc}"
+            self.cdo_command(cdo_command, ensemble=False)
+            # run_this(cdo_command, self, output="ensemble")
 
             return None
 
@@ -142,8 +165,7 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
         else:
             grid_split[cdo_result].append(ff)
         if one_grid:
-            i+=1
-
+            i += 1
 
     if grid is not None:
         # first generate the grid
@@ -167,7 +189,7 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
         # first we need to generate the weights for remapping
         # and add this to the files created list and self.weights
         tracker = open_data(
-            grid_split[key], suppress_messages=True, thredds=self._thredds, checks = False
+            grid_split[key], suppress_messages=True, thredds=self._thredds, checks=False
         )
 
         weights_nc = temp_file("nc")
@@ -193,7 +215,7 @@ def regrid(self, grid=None, method="bil", recycle=False, one_grid = False, **kwa
 
         tracker._execute = True
 
-        run_this(cdo_command, tracker, output="ensemble", suppress = suppress)
+        run_this(cdo_command, tracker, output="ensemble", suppress=suppress)
 
         if recycle is False:
             remove_safe(weights_nc)
