@@ -1,12 +1,22 @@
 import glob
 import os
-from multiprocessing import Manager
-
+import platform
 
 session_info = dict()
-mgr = Manager()
+if platform.system() == "Linux":
+    from multiprocessing import Manager
+
+    nc_safe_par = Manager().list()
+    temp_dirs_par = Manager().list()
+    nc_protected_par = Manager().list()
+else:
+    from multiprocess import Manager
+
+    nc_safe_par = Manager().list()
+    temp_dirs_par = Manager().list()
+    nc_protected_par = Manager().list()
+
 nc_safe = list()
-nc_safe_par = Manager().list()
 
 
 def append_safe(ff):
@@ -76,7 +86,6 @@ def get_protected():
 html_files = []
 
 temp_dirs = list()
-temp_dirs_par = Manager().list()
 
 
 def append_tempdirs(ff):
@@ -102,7 +111,6 @@ def get_tempdirs():
 
 
 nc_protected = list()
-nc_protected_par = Manager().list()
 
 
 def session_files():
