@@ -1,10 +1,5 @@
-import copy
 import warnings
 
-from nctoolkit.cleanup import cleanup
-from nctoolkit.runthis import run_this, run_nco
-from nctoolkit.temp_file import temp_file
-from nctoolkit.session import remove_safe
 from nctoolkit.show import nc_variables
 from nctoolkit.utils import name_check
 
@@ -21,8 +16,9 @@ def set_year(self, x):
 
     if not isinstance(x, int):
         raise ValueError(f"{x} is not a int")
-    cdo_command = f"cdo -setyear,{x}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-setyear,{x}"
+    self.cdo_command(cdo_command, ensemble=False)
+
 
 def set_day(self, x):
     """
@@ -32,13 +28,17 @@ def set_day(self, x):
     -------------
     x : int
         Day to set dataset to
+
+    Examples
+    -------------
+    Set the day to 1 for all time steps, effectively setting the date to the first of the month:
+    >>> ds.set_day(1)
     """
 
     if not isinstance(x, int):
         raise ValueError(f"{x} is not a int")
-    cdo_command = f"cdo -setday,{x}"
-    run_this(cdo_command, self, output="ensemble")
-
+    cdo_command = f"-setday,{x}"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def set_precision(self, x):
@@ -49,6 +49,12 @@ def set_precision(self, x):
     -------------
     x : str
         The precision. One of 'I8', 'I16', 'I32', 'F32', 'F64'.
+
+    Examples
+    -------------
+    Set the precision to 32 bit:
+    >>> ds.set_precision("F32")
+
     """
 
     if x not in ["I8", "I16", "I32", "F32", "F64"]:
@@ -60,6 +66,7 @@ def set_precision(self, x):
 def set_date(self, year=None, month=None, day=None, base_year=1900):
     """
     Set the date in a dataset
+
     You should only do this if you have to fix/change a dataset with a single,
     not multiple dates.
 
@@ -73,6 +80,11 @@ def set_date(self, year=None, month=None, day=None, base_year=1900):
         The day
     base_year : int
         The base year for time creation in the netCDF. Defaults to 1900.
+
+    Examples
+    -------------
+    Set the date to 2000-01-01:
+    >>> ds.set_date(year=2000, month=1, day=1)
     """
 
     if year is None:
@@ -112,11 +124,12 @@ def set_date(self, year=None, month=None, day=None, base_year=1900):
         raise TypeError("day supplied is not an int")
 
     cdo_command = (
-        f"cdo -setreftime,{str(base_year)}-01-01 "
+        f"-setreftime,{str(base_year)}-01-01 "
         f"-setdate,{str(year)}-{str(month)}-{str(day)}"
     )
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
+
 
 def missing_as(self, value=None):
     """
@@ -124,8 +137,15 @@ def missing_as(self, value=None):
 
     Parameters
     -------------
-    value : Number to convert the missing values to
+    value : int/float
         If int/float is provided, the missing value will be converted to that.
+
+    Examples
+    -------------
+    Convert all missing values to 0:
+    >>> ds.missing_as(0)
+
+
     """
 
     try:
@@ -133,20 +153,24 @@ def missing_as(self, value=None):
     except:
         raise TypeError("value must be coercible to float")
 
-    cdo_command = f"cdo -setmisstoc,{value}"
+    cdo_command = f"-setmisstoc,{value}"
+
+    self.cdo_command(cdo_command, ensemble=False)
 
-    run_this(cdo_command, self, output="ensemble")
 
 def set_fill(self, value=None):
     """
-    Set the fill value 
+    Set the fill value
 
     Parameters
     -------------
-    value : 2 variable list or int/float
-        If int/float is provided, the missing value will be set to that.
-        If a list is provided, values between the two values (inclusive)
-        of the list are set to missing.
+    value : int/float
+        The fill value to set.
+
+    Examples
+    -------------
+    Set the fill value to -9999
+    >>> ds.set_fill(-9999)
     """
 
     if value is None:
@@ -157,9 +181,9 @@ def set_fill(self, value=None):
     except:
         raise TypeError("value cannot evaluate to a float")
 
-    cdo_command = f"cdo -setmissval,{value} -setmissval,nan" 
+    cdo_command = f"-setmissval,{value} -setmissval,nan"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def as_missing(self, value=None):
@@ -172,6 +196,16 @@ def as_missing(self, value=None):
         If int/float is provided, the missing value will be set to that.
         If a list is provided, values between the two values (inclusive)
         of the list are set to missing.
+
+    Examples
+    -------------
+    Set all zeros to missing:
+    >>> ds.as_missing(0)
+
+    Set all values between 0 and 1 to missing:
+    >>> ds.as_missing([0, 1])
+
+
     """
 
     if value is None:
@@ -188,12 +222,12 @@ def as_missing(self, value=None):
             raise TypeError(f"{vv} is not an int or float")
 
     if isinstance(value, list):
-        cdo_command = f"cdo -setrtomiss,{str(value[0])},{str(value[1])}"
+        cdo_command = f"-setrtomiss,{str(value[0])},{str(value[1])}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
-def set_units(self, unit_dict=None):
+def set_units(self, unit_dict=None, **kwargs):
     """
     Set the units for variables
 
@@ -202,8 +236,24 @@ def set_units(self, unit_dict=None):
     unit_dict : dict
         A dictionary where the key-value pairs are the variables and
         new units respectively.
+    * kwargs
+        Alternative method for setting units using direct assignment
+
+    Examples
+    -------------
+    Set the units for a variable called 'tas' to 'K':
+    >>> ds.set_units({'tas': 'K'})
+
+    Set the units for a variable called 'tas' to 'K' using kwargs:
+    >>> ds.set_units(tas='K')
+
     """
 
+    if unit_dict is None and len(kwargs) > 0:
+        unit_dict = dict()
+        for kk in kwargs:
+            unit_dict[kk] = kwargs[kk]
+
     if unit_dict is None:
         raise ValueError("Please supply unit_dict")
 
@@ -220,9 +270,11 @@ def set_units(self, unit_dict=None):
         for key in unit_dict:
             if key not in variables:
                 if len(self) > 1:
-                    warnings.warn(message = f"{key} is not in the first file of the dataset")
+                    warnings.warn(
+                        message=f"{key} is not in the first file of the dataset"
+                    )
                 else:
-                    warnings.warn(message = f"{key} is not in the dataset")
+                    warnings.warn(message=f"{key} is not in the dataset")
 
     # change the units in turn. This doesn't seem to be something you can chain?
     for i in unit_dict:
@@ -231,11 +283,11 @@ def set_units(self, unit_dict=None):
         if not isinstance(unit_dict[i], str):
             raise TypeError("key,values in unit_dict are not strings")
 
-        cdo_command = f'cdo -setattribute,{i}@units="{unit_dict[i]}"'
-        run_this(cdo_command, self, output="ensemble")
+        cdo_command = f'-setattribute,{i}@units="{unit_dict[i]}"'
+        self.cdo_command(cdo_command, ensemble=False)
 
 
-def set_longnames(self, name_dict=None):
+def set_longnames(self, name_dict=None, **kwargs):
     """
     Set the long names of variables
 
@@ -244,8 +296,26 @@ def set_longnames(self, name_dict=None):
     name_dict : dict
         Dictionary with key, value pairs representing the variable names and
         their long names
+    * kwargs
+        Alternative method for setting units
+
+    Examples
+    -------------
+    Set the long name of the variable tas to "Temperature" using the dictionary approach:
+    >>> ds.set_longnames(name_dict={"tas": "Temperature"})
+    Alternatively, use the kwargs approach:
+    >>> ds.set_longnames(tas="Temperature")
+
+
+
 
     """
+
+    if name_dict is None and len(kwargs) > 0:
+        name_dict = dict()
+        for kk in kwargs:
+            name_dict[kk] = kwargs[kk]
+
     if name_dict is None:
         raise ValueError("Please supply name_dict")
 
@@ -257,52 +327,29 @@ def set_longnames(self, name_dict=None):
     if not isinstance(name_dict, dict):
         TypeError("A dictionary has not been supplied!")
 
-    # change the units in turn. This doesn't seem to be something you can chain?
-
-    new_commands = []
-    new_files = []
-
     if len(self.history) == len(self._hold_history):
         variables = nc_variables(self[0])
         for key in name_dict:
             if key not in variables:
                 if len(self) > 1:
-                    warnings.warn(message = f"{key} is not in the first file of the dataset")
+                    warnings.warn(
+                        message=f"{key} is not in the first file of the dataset"
+                    )
                 else:
-                    warnings.warn(message = f"{key} is not in the dataset")
+                    warnings.warn(message=f"{key} is not in the dataset")
 
     for key, value in name_dict.items():
         if name_check(key) is False:
             raise ValueError(f"{key} is not a valid netCDF variable name")
 
-    for ff in self:
-        nco_command = "ncatted "
-        for i in name_dict:
-            if not isinstance(i, str):
-                raise TypeError("key,values in name_dict are not strings")
-            if not isinstance(name_dict[i], str):
-                raise TypeError("key,values in name_dict are not strings")
-            i_dict = name_dict[i]
-            i_dict = i_dict.replace('"', "'")
-            nco_command += "-a long_name," + i + ',o,c,"' + i_dict + '" '
+    nco_command = "ncatted "
+    for i in name_dict:
+        if not isinstance(i, str):
+            raise TypeError("key,values in name_dict are not strings")
+        if not isinstance(name_dict[i], str):
+            raise TypeError("key,values in name_dict are not strings")
+        i_dict = name_dict[i]
+        i_dict = i_dict.replace('"', "'")
+        nco_command += "-a long_name," + i + ',o,c,"' + i_dict + '" '
 
-        target = temp_file("nc")
-
-        nco_command += ff + " " + target
-
-        target = run_nco(nco_command, target)
-
-        new_files.append(target)
-        new_commands.append(nco_command)
-
-    self.history += new_commands
-    self._hold_history = copy.deepcopy(self.history)
-
-    self.current = new_files
-
-    for ff in new_files:
-        remove_safe(ff)
-
-    # clean up the directory
-    cleanup()
-    self.disk_clean()
+    self.nco_command(nco_command)
