@@ -1,6 +1,3 @@
-from nctoolkit.runthis import run_this
-
-
 def shift_hours(self, shift=None):
     """
     Shift times in dataset by a number of hours
@@ -20,9 +17,9 @@ def shift_hours(self, shift=None):
     if not isinstance(shift, int):
         raise TypeError("Please supply an int for shift")
 
-    cdo_command = f"cdo -shifttime,{shift}hour"
+    cdo_command = f"-shifttime,{shift}hour"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def shift_days(self, shift=None):
@@ -44,9 +41,9 @@ def shift_days(self, shift=None):
     if not isinstance(shift, int):
         raise TypeError("Please supply an int for shift")
 
-    cdo_command = f"cdo -shifttime,{shift}days"
+    cdo_command = f"-shifttime,{shift}days"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def shift_months(self, shift=None):
@@ -68,9 +65,9 @@ def shift_months(self, shift=None):
     if not isinstance(shift, int):
         raise TypeError("Please supply an int for shift")
 
-    cdo_command = f"cdo -shifttime,{shift}months"
+    cdo_command = f"-shifttime,{shift}months"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def shift_years(self, shift=None):
@@ -92,14 +89,15 @@ def shift_years(self, shift=None):
     if not isinstance(shift, int):
         raise TypeError("Please supply an int for shift")
 
-    cdo_command = f"cdo -shifttime,{shift}years"
+    cdo_command = f"-shifttime,{shift}years"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def shift(self, **kwargs):
     """
-    Shift method. A wrapper for shift_days, shift_hours
+    shift: Shift times in dataset by a number of hours, days, months, or years.
+
     Operations are applied in the order supplied.
 
     Parameters
