@@ -114,17 +114,19 @@ def nc_variables(ff):
         f"cdo showname {ff}", shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
     )
 
-    new = " ".join([
-    x
-    for x in [
-        x
-        for x in cdo_result.stdout.decode("utf-8").split("\n")
-        if "cdo" not in x and len(x) > 0
-    ]
-        if len(x) > 0
-    ])
+    new = " ".join(
+        [
+            x
+            for x in [
+                x
+                for x in cdo_result.stdout.decode("utf-8").split("\n")
+                if "cdo" not in x and len(x) > 0
+            ]
+            if len(x) > 0
+        ]
+    )
     return [x for x in new.split(" ") if len(x) > 0]
-    #return [
+    # return [
     #    x
     #    for x in [
     #        x
@@ -132,7 +134,7 @@ def nc_variables(ff):
     #        if "cdo" not in x and len(x) > 0
     #    ][0].split(" ")
     #    if len(x) > 0
-    #]
+    # ]
 
 
 def nc_months(ff):
