@@ -22,7 +22,6 @@ def split_cdo(self, method="year"):
     bases = []
 
     for ff in self:
-
         # We need to split the file by name
         # But, first we need to check if there is space in the output folder
         # If there isn't, we need to switch to the /var/tmp
@@ -81,7 +80,8 @@ def split_cdo(self, method="year"):
 
 def split(self, by=None):
     """
-    Split the dataset
+    split: Split the dataset
+
     Each file in the ensemble will be separated into new files based on the
     splitting argument.
 
@@ -114,7 +114,7 @@ def split(self, by=None):
     if by == "year":
         method = "year"
 
-    if by == "timestep":
+    if "time" in by: 
         method = "sel,1"
 
     if by == "month":
