@@ -4,9 +4,8 @@ from datetime import datetime, timedelta
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.runthis import run_this
 from nctoolkit.show import nc_years
-from nctoolkit.utils import cdo_version, version_above, name_check
+from nctoolkit.utils import name_check
 
 
 def fix_ind(x):
@@ -16,6 +15,14 @@ def fix_ind(x):
         return int(x) + 1
 
 
+def is_iterable(x):
+    try:
+        y = iter(x)
+        return True
+    except:
+        return False
+
+
 def to_date(x):
     if "-" in x:
         new = x.split("-")
@@ -28,6 +35,7 @@ def to_date(x):
     year = int(new[2])
     return datetime(year, month, day)
 
+
 def select_levels(self, levels=None):
     """
     Select season from a dataset
@@ -52,11 +60,11 @@ def select_levels(self, levels=None):
             raise ValueError("levels provided are not valid!")
         if levels[0] > levels[1]:
             raise ValueError("levels have the wrong order")
-        levels = f"{levels[0]}/{levels[1]}" 
+        levels = f"{levels[0]}/{levels[1]}"
 
-    cdo_command =  f"cdo -sellevel,{levels}"
-        
-    run_this(cdo_command, self, "ensemble")
+    cdo_command = f"-sellevel,{levels}"
+
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_period(self, period=None):
@@ -91,9 +99,9 @@ def select_period(self, period=None):
     start = str(period[0]).split(" ")[0]
     end = period[1] - timedelta(days=1)
     end = str(end).split(" ")[0]
-    cdo_command = f"cdo -seldate,{start},{end}"
+    cdo_command = f"-seldate,{start},{end}"
 
-    run_this(cdo_command, self, "ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_seasons(self, season=None):
@@ -115,8 +123,9 @@ def select_seasons(self, season=None):
     if season not in ["DJF", "MAM", "JJA", "SON"]:
         raise ValueError("Invalid season supplied")
 
-    cdo_command = f"cdo -select,season={season}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-select,season={season}"
+    self.cdo_command(cdo_command, ensemble=False)
+
 
 def select_hours(self, hours=None):
     """
@@ -145,7 +154,6 @@ def select_hours(self, hours=None):
 
     hours = [int(x) if "int" in str(type(x)) else x for x in hours]
 
-
     for x in hours:
         if not isinstance(x, int):
             raise TypeError(f"{x} is not an int")
@@ -154,8 +162,8 @@ def select_hours(self, hours=None):
 
     hours = str_flatten(hours, ",")
 
-    cdo_command = f"cdo -selhour,{hours}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-selhour,{hours}"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_days(self, days=None):
@@ -185,7 +193,6 @@ def select_days(self, days=None):
 
     days = [int(x) if "int" in str(type(x)) else x for x in days]
 
-
     for x in days:
         if not isinstance(x, int):
             raise TypeError(f"{x} is not an int")
@@ -194,8 +201,8 @@ def select_days(self, days=None):
 
     days = str_flatten(days, ",")
 
-    cdo_command = f"cdo -selday,{days}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-selday,{days}"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_months(self, months=None):
@@ -225,7 +232,6 @@ def select_months(self, months=None):
 
     months = [int(x) if "int" in str(type(x)) else x for x in months]
 
-
     for x in months:
         if not isinstance(x, int):
             raise TypeError(f"{x} is not an int")
@@ -234,8 +240,8 @@ def select_months(self, months=None):
 
     months = str_flatten(months, ",")
 
-    cdo_command = f"cdo -selmonth,{months}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-selmonth,{months}"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_years(self, years=None):
@@ -267,7 +273,6 @@ def select_years(self, years=None):
             raise TypeError(f"{yy} is not an int")
 
     if self._merged is False:
-
         missing_files = 0
 
         n_removed = 0
@@ -275,14 +280,12 @@ def select_years(self, years=None):
         # loop through all of the files and remove any that do not have valid years
         new_current = []
 
-
         all_check = []
 
         for ff in self:
-
             all_years = nc_years(ff)
             all_years = list(set(all_years))
-            all_check+=all_years
+            all_check += all_years
             all_years = [int(v) for v in all_years]
             inter = [element for element in all_years if element in years]
 
@@ -311,9 +314,13 @@ def select_years(self, years=None):
         if len(missing_years) > 0:
             len_missing = len(missing_years)
             missing_years = [int(x) for x in missing_years]
-            if set(range(min(missing_years), max(missing_years) + 1)) == set(missing_years):
+            if set(range(min(missing_years), max(missing_years) + 1)) == set(
+                missing_years
+            ):
                 if len(missing_years) > 1:
-                    missing_years = str(min(missing_years)) + "-" + str(max(missing_years))
+                    missing_years = (
+                        str(min(missing_years)) + "-" + str(max(missing_years))
+                    )
                 else:
                     missing_years = str(missing_years[0])
             else:
@@ -321,24 +328,28 @@ def select_years(self, years=None):
                 missing_years = str_flatten(missing_years, ",")
             if missing_files == 0:
                 if len_missing == 1:
-                    warnings.warn(f"The following year was not available in the dataset: {missing_years}")
+                    warnings.warn(
+                        f"The following year was not available in the dataset: {missing_years}"
+                    )
                 else:
-                    warnings.warn(f"{len_missing} years were not available in the dataset: {missing_years}")
+                    warnings.warn(
+                        f"{len_missing} years were not available in the dataset: {missing_years}"
+                    )
 
         self.current = new_current
 
         if missing_files > 0:
             years = str_flatten(years, ",")
 
-            cdo_command = f"cdo -selyear,{years}"
+            cdo_command = f"-selyear,{years}"
 
-            run_this(cdo_command, self, output="ensemble")
+            self.cdo_command(cdo_command, ensemble=False)
     else:
         years = str_flatten(years, ",")
 
-        cdo_command = f"cdo -selyear,{years}"
+        cdo_command = f"-selyear,{years}"
 
-        run_this(cdo_command, self, output="one")
+        self.cdo_command(cdo_command, ensemble=True)
 
     cleanup()
 
@@ -372,9 +383,9 @@ def select_variables(self, vars=None):
 
     vars_list = str_flatten(vars_list, ",")
 
-    cdo_command = f"cdo -selname,{vars_list}"
+    cdo_command = f"-selname,{vars_list}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def select_timesteps(self, times=None):
@@ -400,9 +411,6 @@ def select_timesteps(self, times=None):
     for tt in times:
         if not isinstance(tt, int):
             raise TypeError(f"{tt} is not an int")
-        if tt < 0:
-            if version_above(cdo_version(), "2.0.0") is False:
-                raise ValueError(f"Please install CDO version 2.0.5 or above for negative timestep selections")
 
     # all of the variables in months need to be converted to ints,
     # just in case floats have been provided
@@ -411,14 +419,15 @@ def select_timesteps(self, times=None):
     times = [str(x) for x in times]
     times = str_flatten(times)
 
-    cdo_command = f"cdo -seltimestep,{times}"
+    cdo_command = f"-seltimestep,{times}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def subset(self, **kwargs):
     """
-    A method for subsetting datasets to specific variables, years, longitudes etc.
+    subset: A method for subsetting datasets to specific variables, years, longitudes etc.
+
     Operations are applied in the order supplied.
 
     Parameters
@@ -454,10 +463,10 @@ def subset(self, **kwargs):
 
     lon: list
         The longitude range to select. This must be two variables,
-        between -180 and 180.
+        between -180 and 180. The variables should be the minimum and maximum longitude.
     lat: list
         The latitude range to select. This must be two variables,
-        between -90 and 90.
+        between -90 and 90. The variables should be the minimum and maximum latitude.
 
     levels : list
         List of the form [min_level, max_level]. Levels/depths between the two will be selected
@@ -490,6 +499,17 @@ def subset(self, **kwargs):
 
 
     """
+    for kk in kwargs:
+        if is_iterable(kwargs[kk]):
+            ints = True
+            for x in kwargs[kk]:
+                try:
+                    y = int(x)
+                except:
+                    ints = False
+
+                if ints:
+                    kwargs[kk] = kwargs[kk]
 
     non_selected = True
 
@@ -501,11 +521,16 @@ def subset(self, **kwargs):
         if "lat" in key.lower():
             lat = kwargs[key]
     if lon is not None or lat is not None:
-        self.crop(lon = lon, lat = lat)
+        if "nco" in kwargs:
+            if kwargs["nco"] is True:
+                self.crop(lon=lon, lat=lat, nco = True)
+            else:
+                self.crop(lon=lon, lat=lat)
+        else:
+            self.crop(lon=lon, lat=lat)
         non_selected = False
 
     for key in kwargs:
-
         if "ran" in key.lower():
             select_period(self, kwargs[key])
             non_selected = False
@@ -542,6 +567,5 @@ def subset(self, **kwargs):
             select_levels(self, kwargs[key])
             non_selected = False
 
-
     if non_selected:
         raise AttributeError(f"{key} is not a valid select method")
