@@ -6,7 +6,8 @@ import nctoolkit.api as api
 
 def first_above(self, x=None):
     """
-    Identify the time step when a value is first above a threshold
+    first_above: Identify the time step when a value is first above a threshold.
+
     This will do the comparison with either a number, a Dataset or a netCDF file.
 
     Parameters
@@ -60,7 +61,7 @@ def first_above(self, x=None):
         self.rename({self.variables[0]: "target"})
         self.as_missing([-1, 0.1])
         if old:
-            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True)
+            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True,)
         else:
             self.assign( new=lambda x: (x.target == x.target) * (timestep() + 1), drop=True)
         self.as_missing([0, 0.01])
@@ -75,7 +76,7 @@ def first_above(self, x=None):
 
 def first_below(self, x=None):
     """
-    Identify the time step when a value is first below a threshold
+    first_below: Identify the time step when a value is first below a threshold
     This will do the comparison with either a number, a Dataset or a netCDF file.
 
     Parameters
@@ -131,7 +132,7 @@ def first_below(self, x=None):
         self.rename({self.variables[0]: "target"})
         self.as_missing([-1, 0.1])
         if old:
-            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True)
+            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True,)
         else:
             self.assign( new=lambda x: (x.target == x.target) * (timestep() + 1), drop=True)
         self.as_missing([0, 0.01])
@@ -146,7 +147,7 @@ def first_below(self, x=None):
 
 def last_above(self, x=None):
     """
-    Identify the final time step when a value is above a threshold
+    last_above: Identify the final time step when a value is above a threshold
     This will do the comparison with either a number, a Dataset or a netCDF file.
 
     Parameters
@@ -205,7 +206,7 @@ def last_above(self, x=None):
         self.rename({self.variables[0]: "target"})
         self.as_missing([-1, 0.1])
         if old:
-            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True)
+            self.assign( new=lambda x: (x.target == x.target) * (timestep(x.target) + 1), drop=True,)
         else:
             self.assign( new=lambda x: (x.target == x.target) * (timestep() + 1), drop=True)
         self.as_missing([0, 0.01])
@@ -222,7 +223,7 @@ def last_above(self, x=None):
 
 def last_below(self, x=None):
     """
-    Identify the last time step when a value is below a threshold
+    last_below: Identify the last time step when a value is below a threshold
     This will do the comparison with either a number, a Dataset or a netCDF file.
 
     Parameters
@@ -281,7 +282,7 @@ def last_below(self, x=None):
         self.rename({self.variables[0]: "target"})
         self.as_missing([-1, 0.1])
         if old:
-            self.assign( new=lambda x: (x.target == x.target) * -1 * (timestep(x.target) + 1), drop=True)
+            self.assign( new=lambda x: (x.target == x.target) * -1 * (timestep(x.target) + 1), drop=True,)
         else:
             self.assign( new=lambda x: (x.target == x.target) * -1 * (timestep() + 1), drop=True)
         self.as_missing([0, 0.01])
