@@ -4,7 +4,7 @@ import xarray as xr
 
 def to_xarray(self, decode_times=True, **kwargs):
     """
-    Open a dataset as an xarray object
+    to_xarray: Open a dataset as an xarray object
 
     Parameters
     -------------
@@ -46,7 +46,6 @@ def to_xarray(self, decode_times=True, **kwargs):
     if len(kwargs) == 0:
         self.run()
 
-
     self1 = self.copy()
 
     if len(kwargs) > 0:
@@ -90,7 +89,6 @@ def to_xarray(self, decode_times=True, **kwargs):
     # then push those to the xarray object
 
     if len(self1) == 1:
-
         if isinstance(self1.times[0], datetime):
             times = self1.times
         else:
@@ -106,7 +104,7 @@ def to_xarray(self, decode_times=True, **kwargs):
 
 def to_dataframe(self, decode_times=True, **kwargs):
     """
-    Open a dataset as a pandas data frame
+    to_dataframe: Convert a dataset to a pandas data frame
 
     Parameters
     -------------
@@ -120,5 +118,11 @@ def to_dataframe(self, decode_times=True, **kwargs):
     ---------------
     to_dataframe :  pandas.DataFrame
 
+    Examples
+    ------------
+    If you want to convert a dataset to a pandas data frame, do the following:
+
+    >>> ds.to_dataframe()
+
     """
     return self.to_xarray(decode_times=decode_times, **kwargs).to_dataframe()
