@@ -1,24 +1,46 @@
-import copy
 import subprocess
 import warnings
-import os
-
-from nctoolkit.api import open_data
+import copy
 from nctoolkit.cleanup import cleanup
+from nctoolkit.api import open_data
 from nctoolkit.flatten import str_flatten
-from nctoolkit.runthis import run_this, run_cdo
-from nctoolkit.temp_file import temp_file
-from nctoolkit.session import append_safe
-from nctoolkit.session import remove_safe
-from nctoolkit.utils import version_above, cdo_version
 import nctoolkit.api as api
 
+# method to generate level bounds
+
+def generate_level_bounds(self):
+    """
+    generate_level_bounds: Generate level bounds for a dataset
+
+    This method will generate level bounds for a dataset.
+
+    Internally, this will use CDO's method genlevelbounds, which will generate the bounds based on the vertical levels in the dataset.
+    In most cases, this will result in something sensible. However, you may want to check output in case the vertical levels are very irregular.
+
+
+
+    Examples
+    ------------
+
+    If you wanted to generate level bounds for a dataset, do the following:
+
+    >>> ds.generate_level_bounds()
+
+    """
+
+    self.cdo_command("-genlevelbounds", ensemble=False)
+
+
 
 def bottom(self):
     """
-    Extract the bottom level from a dataset
+    bottom: Extract the bottom level from a dataset
+
     This extracts the bottom level from each netCDF file. Please note that for
     ensembles, it uses the first file to derive the index of the bottom level.
+
+    You may need to double check that the bottom vertical level is the sea 'bottom' etc., as this is not always the case.
+
     Use bottom_mask for files when the bottom cell in netCDF files do not represent
     the actual bottom.
 
@@ -52,16 +74,21 @@ def bottom(self):
         str(cdo_result).replace("b'", "").strip().replace("'", "").split("\\n")[0]
     )
 
-    cdo_command = f"cdo -sellevidx,{str(n_levels)}"
+    cdo_command = f"-sellevidx,{str(n_levels)}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def top(self):
     """
-    Extract the top/surface level from a dataset
+    top: Extract the top/surface level from a dataset
+
     This extracts the first vertical level from each file in a dataset.
 
+    This method is most useful for things like oceanic data, where this method will extract the sea surface.
+
+    You may need to double check that the first vertical level is the surface, as this is not always the case.
+
     Examples
     ------------
 
@@ -69,18 +96,23 @@ def top(self):
 
     >>> ds.top()
 
-    This method is most useful for things like oceanic data, where this method will extract the sea surface.
     """
 
-    cdo_command = "cdo -sellevidx,1"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = "-sellevidx,1"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
-def vertical_interp(self, levels=None, fixed = None, thickness = None):
+def vertical_interp(
+    self, levels=None, fixed=None, thickness=None, depths=None, surface=None
+):
     """
-    Verticaly interpolate a dataset based on given vertical levels
-    This is calculated for each time step and grid cell
-    Note: This requires consistent vertical levels in space. For the likes of sigma-coordinates,
+    vertical_interp: Verticaly interpolate a dataset based on given vertical levels
+
+    Vertical interpolation is calculated for each time step and grid cell
+
+    Note
+    ------
+    This requires consistent vertical levels in space. For the likes of sigma-coordinates,
     please use to_zlevels.
 
     Parameters
@@ -88,16 +120,26 @@ def vertical_interp(self, levels=None, fixed = None, thickness = None):
     levels : list, int or str
         list of vertical levels, for example depths for an ocean model, to vertically
         interpolate to. These must be floats or ints.
-    fixed : bool 
+    fixed : bool
         Define whether the vertical levels are the same in all spatial locations.
         Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
-        set this to True. 
+        set this to False.
     thickness: str or Dataset
-        This must be supplied if fixed is False, otherwise vertical thickness cannot be known.
+        This or depths must be supplied if fixed is False, otherwise vertical thickness/depth cannot be known.
         Option argument when vertical levels vary in space.
         One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
         the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
         one variable. Thickness should be in metres. Vertical interpolation will take the value from the mid-point of the level.
+    depths: str or Dataset
+        This or thickness must be supplied if fixed is False, otherwise vertical thickness/depth cannot be known.
+        Option argument when vertical levels vary in space.
+        One of: a variable, in the dataset, which contains the variable depths; a .nc file which contains
+        the depths; or a Dataset that contains the depths. Note: the .nc file or Dataset must only contain
+        one variable. Depths should be in metres, and be the mid-point of the level.
+    surface: str
+        If thickness is supplied you must also supply this to identify whether the top or bottom of the level is the surface, i.e. the lowest level.
+        This must be one of 'top' or 'bottom'.
+
 
     Examples
     ------------
@@ -111,13 +153,25 @@ def vertical_interp(self, levels=None, fixed = None, thickness = None):
 
     """
 
+    # check surface
+
+    if surface is not None:
+        if surface not in ["top", "bottom"]:
+            raise ValueError("Surface must be one of 'top' or 'bottom'")
+
+    if thickness is not None:
+        if depths is not None:
+            if surface is None:
+                raise ValueError("Please provide surface")
+
     if fixed is None:
         if thickness is None:
             raise ValueError("You must provide the fixed arg")
 
-    if fixed is False:
-        if thickness is None:
-            raise ValueError("Please provide thickness")
+    if depths is None:
+        if fixed is False:
+            if thickness is None:
+                raise ValueError("Please provide thickness")
 
     if not isinstance(fixed, bool):
         if thickness is None:
@@ -127,7 +181,9 @@ def vertical_interp(self, levels=None, fixed = None, thickness = None):
         fixed = False
 
     if fixed is False:
-        self.to_zlevels(levels = levels, thickness = thickness)
+        self.to_zlevels(
+            levels=levels, thickness=thickness, depths=depths, surface=surface
+        )
         return None
 
     if levels is None:
@@ -138,43 +194,44 @@ def vertical_interp(self, levels=None, fixed = None, thickness = None):
     if isinstance(levels, (int, float)):
         levels = [levels]
 
-    #levels = [float(x) for x in levels]
+    # levels = [float(x) for x in levels]
 
     for vv in levels:
         if not isinstance(vv, (int, float)):
             raise TypeError(f"{vv} is not a valid depth")
 
     levels = str_flatten(levels, ",")
-    cdo_command = f"cdo -intlevel,{levels}"
+    cdo_command = f"-intlevel,{levels}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
 
 def vertstat(self, stat="mean"):
     """Method to calculate the vertical mean from a function"""
-    cdo_command = f"cdo -vert{stat}"
-    run_this(cdo_command, self, output="ensemble")
+    cdo_command = f"-vert{stat}"
+    self.cdo_command(cdo_command, ensemble=False)
 
 
-def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
+def vertical_mean(self, thickness=None, depth_range=None, fixed=None):
     """
-    Calculate the depth-averaged mean for each variable
-    This is calculated for each time step and grid cell
+    vertical_mean: Calculate the depth-averaged mean for each variable.
+
+    This is calculated for each time step and grid cell.
 
     Optional parameters
     -------------
     thickness: str or Dataset
-        This mube be supplied when vertical levels vary in space, i.e. fixed=False.
+        This must be supplied when vertical levels vary in space, i.e. fixed=False.
         One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
         the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
         one variable.
     depth_range: list
         Only use when vertical levels vary in space
         Set a depth range if desired. Should be of the form [min_depth, max_depth].
-    fixed : bool 
+    fixed : bool
         Define whether the vertical levels are the same in all spatial locations.
         Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
-        set this to True. 
+        set this to True.
 
     Examples
     ------------
@@ -202,7 +259,6 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
         return None
 
     if isinstance(depth_range, list):
-
         if len(depth_range) != 2:
             raise ValueError("Please provide a 2 variable list for depth range")
         if depth_range[1] <= depth_range[0]:
@@ -221,7 +277,9 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
     self1 = self.copy()
 
     if len(self) > 1:
-        warnings.warn("Vertical structure will be assumed to be the same for all files in the dataset")
+        warnings.warn(
+            "Vertical structure will be assumed to be the same for all files in the dataset"
+        )
 
     # Set up the thickness
 
@@ -236,7 +294,7 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
     drop_this = None
     if sorted is False:
         if thickness in self.variables:
-            ds_thick = open_data(self[0]) 
+            ds_thick = open_data(self[0])
             ds_thick.subset(variable=thickness)
             ds_thick.run()
             drop_this = thickness
@@ -248,7 +306,6 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
     thick_var = ds_thick.variables[0]
     # modify the depth if it is a list
     if isinstance(depth_range, list):
-
         ds_thick.rename({thick_var: "thickness"})
         ds_thick.run()
         ds_depth = ds_thick.copy()
@@ -264,12 +321,14 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
 
     self1.subset(variables=self.contents.query("nlevels > 1").variable)
     if drop_this is not None:
-        self1.drop(variables = drop_this)
+        self1.drop(variables=drop_this)
 
     ds_thick.run()
     self1.run()
     self1.multiply(ds_thick)
-    warnings.warn(message = "Assuming missing values are in the same grid cells in thickness and variable data. Modify thickness and re-run if they are not.")
+    warnings.warn(
+        message="Assuming missing values are in the same grid cells in thickness and variable data. Modify thickness and re-run if they are not."
+    )
     self1.run()
     self1.vertical_sum()
     self1.run()
@@ -282,7 +341,6 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
     if isinstance(depth_range, list):
         del ds_depth
 
-
     self.current = self1.current
     self.history = self1.history
     self._hold_history = self1._hold_history
@@ -290,8 +348,9 @@ def vertical_mean(self, thickness=None, depth_range=None, fixed = None):
 
 def vertical_min(self):
     """
-    Calculate the vertical minimum of variable values
-    This is calculated for each time step and grid cell
+    vertical_min: Calculate the vertical minimum of variable values.
+
+    This is calculated for each time step and grid cell.
 
     Examples
     ------------
@@ -306,8 +365,9 @@ def vertical_min(self):
 
 def vertical_max(self):
     """
-    Calculate the vertical maximum of variable values
-    This is calculated for each time step and grid cell
+    vertical_max: Calculate the vertical maximum of variable values.
+
+    This is calculated for each time step and grid cell.
 
     Examples
     ------------
@@ -322,8 +382,9 @@ def vertical_max(self):
 
 def vertical_range(self):
     """
-    Calculate the vertical range of variable values
-    This is calculated for each time step and grid cell
+    vertical_range: Calculate the vertical range of variable values.
+
+    This is calculated for each time step and grid cell.
 
     Examples
     ------------
@@ -336,9 +397,10 @@ def vertical_range(self):
     vertstat(self, stat="range")
 
 
-def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
+def vertical_integration(self, thickness=None, depth_range=None, fixed=None):
     """
-    Calculate the vertically integrated sum over the water column
+    vertical_integration: Calculate the vertically integrated sum over the water column.
+
     This calculates the sum of the variable multiplied by the cell thickness
 
     Parameters
@@ -346,58 +408,57 @@ def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
     thickness: str or Dataset
         This must be supplied when vertical levels vary spatially.
         One of: a variable, in the dataset, which contains the variable thicknesses; a .nc file which contains
-        the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or Dataset must only contain
+        the thicknesses; or a Dataset that contains the thicknesses. Note: the .nc file or DataSet must only contain
         one variable.
     depth_range: list
         Set a depth range if desired. Should be of the form [min_depth, max_depth].
-    fixed : bool 
+    fixed : bool
         Define whether the vertical levels are the same in all spatial locations.
         Set to True if they are, e.g. you have z-levels. If you have the likes of sigma-coordinates,
-        set this to True. 
+        set this to True.
 
     Examples
     ------------
 
-    If you wanted to sum of values across all vertical levels of every variable in a dataset that has spatially fixed vertical levels, you would do this:
+    If you wanted to integrate values across all vertical levels of every variable in a dataset that has spatially fixed vertical levels, you would do this:
 
-    >>> ds.vertical_sum(fixed = True)
+    >>> ds.vertical_integration(fixed = True)
 
     """
     if fixed is None and thickness is None:
         raise ValueError("Please state if levels are fixed or provide thickness")
 
     if fixed:
-        if version_above(cdo_version(), "2.0.0") is False:
-            raise ValueError("Please install CDO>2.0.0")
         warnings.warn("Extracting vertical thickness from dataset level data")
         var = list(self.contents.query("nlevels > 1").variable)[0]
 
         ff = self[0]
         command = f"cdo zaxisdes {ff}"
         out = subprocess.Popen(
-                 command,
-                 shell=True,
-                 stdin=subprocess.PIPE,
-                 stdout=subprocess.PIPE,
-                 stderr=subprocess.STDOUT,
-             )
+            command,
+            shell=True,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+        )
         result, ignore = out.communicate()
 
         if "bounds" not in result.decode("utf-8").lower():
-            raise ValueError("Vertical bounds info does not appear to be in the netCDF files, so thicknesses cannot be calculated for vertical integration!")
+            raise ValueError(
+                "Vertical bounds info does not appear to be in the netCDF files, so thicknesses cannot be calculated for vertical integration!"
+            )
 
         thickness = self.copy()
-        thickness.subset(time = 0, variable = var)
-        thickness.rename({var:"thickness"})
-        thickness.assign(thickness = lambda x: (isnan(x.thickness) == False) * level(x.thickness), drop = True)
-        thickness.assign(thickness = lambda x: thickness(x.thickness) + (x.thickness < x.thickness), drop = True)
+        thickness.subset(time=0, variable=var)
+        thickness.rename({var: "thickness"})
+        thickness.assign( thickness=lambda x: (isnan(x.thickness) is False) * level(x.thickness), drop=True,)
+        thickness.assign( thickness=lambda x: thickness(x.thickness) + (x.thickness < x.thickness), drop=True,)
         thickness.run()
-    
+
     if thickness is None:
         raise ValueError("Please specify thickness")
 
     if isinstance(depth_range, list):
-
         if len(depth_range) != 2:
             raise ValueError("Please provide a 2 variable list for depth range")
         if depth_range[1] <= depth_range[0]:
@@ -415,7 +476,9 @@ def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
     self.run()
 
     if len(self) > 1:
-        warnings.warn("Vertical integration will assume all files have the same structure")
+        warnings.warn(
+            "Vertical integration will assume all files have the same structure"
+        )
 
     # Set up the thickness
 
@@ -443,7 +506,6 @@ def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
     thick_var = ds_thick.variables[0]
     # modify the depth if it is a list
     if isinstance(depth_range, list):
-
         if thick_var != "thickness":
             ds_thick.rename({thick_var: "thickness"})
             ds_thick.run()
@@ -461,7 +523,7 @@ def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
 
     self1.subset(variables=self1.contents.query("nlevels > 1").variable)
     if drop_this is not None:
-        self1.drop(variables = drop_this)
+        self1.drop(variables=drop_this)
 
     ds_thick.run()
     self1.run()
@@ -480,8 +542,9 @@ def vertical_integration(self, thickness=None, depth_range=None, fixed = None):
 
 def vertical_sum(self):
     """
-    Calculate the vertical sum of variable values
-    This is calculated for each time step and grid cell
+    vertical_sum: Calculate the vertical sum of variable values.
+
+    This is calculated for each time step and grid cell.
 
     Examples
     ------------
@@ -496,8 +559,9 @@ def vertical_sum(self):
 
 def vertical_cumsum(self):
     """
-    Calculate the vertical sum of variable values
-    This is calculated for each time step and grid cell
+    vertical_cumsum: Calculate the vertical sum of variable values.
+
+    This is calculated for each time step and grid cell.
 
     Examples
     ------------
@@ -511,31 +575,25 @@ def vertical_cumsum(self):
     vertstat(self, stat="cum")
 
 
-def invert_levels(self):
+def bottom_mask(self):
     """
-    Invert the levels of 3D variables
-    This is calculated for each time step and grid cell
+    bottom_mask: Create a mask identifying the deepest cell without missing values..
+
+    This converts a dataset to a mask identifying which cell represents the bottom,
+    for example the seabed. 1 identifies the deepest cell with non-missing values.
+    Everything else is 0, or missing.
+
+    Note
+    ------
+    This will only work for single file datasets.
+    The method will modify the dataset in place, so make a copy if you want to keep the original.
 
     Examples
     ------------
 
-    If you wanted to invert the vertical levels, you would do this:
+    If you wanted to create a mask identifying the bottom, you would do this:
 
-    >>> ds.invert_levels()
-
-    """
-    cdo_command = "cdo -invertlev"
-
-    run_this(cdo_command, self, output="ensemble")
-
-
-def bottom_mask(self):
-    """
-    Create a mask identifying the deepest cell without missing values.
-    This converts a dataset to a mask identifying which cell represents the bottom,
-    for example the seabed. 1 identifies the deepest cell with non-missing values.
-    Everything else is 0, or missing. At present this method only uses the first
-    available variable from netCDF files, so it may not be suitable for all data
+    >>> ds.bottom_mask()
     """
     self.run()
 
@@ -550,7 +608,7 @@ def bottom_mask(self):
     data.subset(variables=var_use)
     data.subset(timesteps=0)
     data.as_missing([0, 0])
-    data.cdo_command(f"expr,'Wet={var_use}=={var_use}'")
+    data.cdo_command(f"-expr,'Wet={var_use}=={var_use}'")
     data.invert_levels()
     data.run()
     bottom = data.copy()
@@ -570,22 +628,24 @@ def bottom_mask(self):
 
     cleanup()
 
+
 def surface_mask(self):
     """
-    Create a mask identifying the shallowest cell without missing values.
+    surface_mask: Create a mask identifying the shallowest cell without missing values.
+
     This converts a dataset to a mask identifying which cell represents top level,
     for example the sea surface. 1 identifies the shallowest cell with non-missing values.
     Everything else is 0, or missing. At present this method only uses the first
     available variable from netCDF files, so it may not be suitable for all data
+
+    Examples
+    ------------
+
+    If you wanted to create a mask identifying the surface, you would do this:
+
+    >>> ds.surface_mask()
     """
 
     self.invert_levels()
     self.bottom_mask()
     self.invert_levels()
-
-
-
-
-
-
-
