@@ -1,4 +1,3 @@
-from nctoolkit.runthis import run_this
 from nctoolkit.utils import is_curvilinear
 from nctoolkit.api import open_data
 
@@ -10,19 +9,19 @@ def zonstat(self, stat="mean"):
         if is_curvilinear(ff):
             raise TypeError(f"zonal_{stat} cannot be calculated for curvilinear grids.")
 
-    cdo_command = f"cdo -zon{stat}"
+    cdo_command = f"-zon{stat}"
 
-    run_this(cdo_command, self, output="ensemble")
+    self.cdo_command(cdo_command, ensemble=False)
 
-def zonal_sum(self, by_area = False):
+
+def zonal_sum(self, by_area=False):
     """
-    Calculate the zonal sum for each year/month combination in files.
-    This applies to each file in an ensemble.
+    zonal_sum: Calculate the zonal sum for each time step
 
     Parameters
     -------------
-    by_area : bool 
-        Set to True if you want the cell value to be multiplied by the cell area prior to summing 
+    by_area : bool
+        Set to True if you want the cell value to be multiplied by the cell area prior to summing
 
     Examples
     ------------
@@ -35,16 +34,16 @@ def zonal_sum(self, by_area = False):
         if len(self) > 1:
             print("Using first file in the dataset for areas")
         ds_area = open_data(self[0])
-        ds_area.subset(time = 0)
-        ds_area.cell_area(join = False)
+        ds_area.subset(time=0)
+        ds_area.cell_area(join=False)
         self.multiply(ds_area)
 
     zonstat(self, stat="sum")
 
+
 def zonal_mean(self):
     """
-    Calculate the zonal mean for each year/month combination in files.
-    This applies to each file in an ensemble.
+    zonal_mean: Calculate the zonal mean for each time step
 
     Examples
     ------------
@@ -58,8 +57,7 @@ def zonal_mean(self):
 
 def zonal_min(self):
     """
-    Calculate the zonal minimum for each year/month combination in files.
-    This applies to each file in an ensemble.
+    zonal_min: Calculate the zonal minimum for each time step
 
     Examples
     ------------
@@ -72,8 +70,7 @@ def zonal_min(self):
 
 def zonal_max(self):
     """
-    Calculate the zonal maximum for each year/month combination in files.
-    This applies to each file in an ensemble.
+    zonal_max: Calculate the zonal maximum for each time step
 
     Examples
     ------------
@@ -86,8 +83,7 @@ def zonal_max(self):
 
 def zonal_range(self):
     """
-    Calculate the zonal range for each year/month combination in files.
-    This applies to each file in an ensemble.
+    zonal_range: Calculate the zonal range for each time step
 
     Examples
     ------------
